@@ -1,5 +1,6 @@
+from typing import Any, Dict
+
 from samtranslator.model import Resource
-from typing import Dict, Any
 
 do_not_verify = {
     # type_after_transform: type_before_transform
@@ -15,16 +16,20 @@ do_not_verify = {
     "AWS::ApiGateway::DomainName": "AWS::ApiGateway::DomainName",
     "AWS::ApiGateway::BasePathMapping": "AWS::ApiGateway::BasePathMapping",
     "AWS::StepFunctions::StateMachine": "AWS::Serverless::StateMachine",
+    "AWS::AppSync::GraphQLApi": "AWS::Serverless::GraphQLApi",
 }
 
 
 def verify_unique_logical_id(resource: Resource, existing_resources: Dict[str, Any]) -> bool:
+    """Return true if the logical id is unique."""
+
     # new resource logicalid exists in the template before transform
-    if resource.logical_id is not None and resource.logical_id in existing_resources:
-        # new resource logicalid is in  the do_not_resolve list
-        if (
-            resource.resource_type not in do_not_verify
-            or existing_resources[resource.logical_id]["Type"] not in do_not_verify[resource.resource_type]
-        ):
-            return False
-    return True
+    if resource.logical_id is None or resource.logical_id not in existing_resources:
+        return True
+    # new resource logicalid is in  the do_not_resolve list
+    if (
+        resource.resource_type in do_not_verify
+        and existing_resources[resource.logical_id]["Type"] in do_not_verify[resource.resource_type]
+    ):
+        return True
+    return False
